@@ -459,7 +459,7 @@ create_sys_view (ProcData *procdata)
 			    TRUE,
 			    0);
 */
-	gtk_widget_set_size_request(GTK_WIDGET(load_graph_get_labels(net_graph)->net_in), 65, -1);
+	gtk_widget_set_size_request(GTK_WIDGET(load_graph_get_labels(net_graph)->net_in), 100, -1);
 	gtk_table_attach (GTK_TABLE (table), load_graph_get_labels(net_graph)->net_in, 2, 3, 0, 1, 
 			  static_cast<GtkAttachOptions>(GTK_EXPAND | GTK_FILL), GTK_FILL, 0, 0);
 
@@ -515,7 +515,7 @@ create_sys_view (ProcData *procdata)
 			    TRUE,
 			    0);
 */
-	gtk_widget_set_size_request(GTK_WIDGET(load_graph_get_labels(net_graph)->net_out), 65, -1);
+	gtk_widget_set_size_request(GTK_WIDGET(load_graph_get_labels(net_graph)->net_out), 100, -1);
 	gtk_table_attach (GTK_TABLE (table), load_graph_get_labels(net_graph)->net_out, 2, 3, 0, 1, 
 			  static_cast<GtkAttachOptions>(GTK_EXPAND | GTK_FILL), GTK_FILL, 0, 0);
 
@@ -619,11 +619,11 @@ create_main_window (ProcData *procdata)
 	gtk_window_set_title(GTK_WINDOW(app), _("System Monitor"));
 
 	GdkScreen* screen = gtk_widget_get_screen(app);
-	GdkColormap* colormap = gdk_screen_get_rgba_colormap(screen);
+	GdkVisual* visual = gdk_screen_get_rgba_visual(screen);
 
-	/* use rgba colormap, if available */
-	if (colormap)
-		gtk_widget_set_default_colormap(colormap);
+	/* use visual, if available */
+	if (visual)
+            gtk_widget_set_visual(app, visual);
 
 	main_box = gtk_vbox_new (FALSE, 0);
 	gtk_container_add(GTK_CONTAINER(app), main_box);
@@ -797,12 +797,11 @@ static void
 cb_toggle_tree (GtkAction *action, gpointer data)
 {
 	ProcData *procdata = static_cast<ProcData*>(data);
-	GConfClient *client = procdata->client;
-	gboolean show;
+	GSettings *settings = procdata->settings;	gboolean show;
 
 	show = gtk_toggle_action_get_active (GTK_TOGGLE_ACTION (action));
 	if (show == procdata->config.show_tree)
 		return;
 
-	gconf_client_set_bool (client, "/apps/procman/show_tree", show, NULL);
+	g_settings_set_boolean (settings, "show_tree", show);
 }
